==> codebuild-1.60.0-sources.jar: software/amazon/awscdk/services/codebuild/Cache.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * Cache options for CodeBuild Project.
 * <p>
 * A cache can store reusable pieces of your build environment and use them across multiple builds.
 * <p>
 * @see https://docs.aws.amazon.com/codebuild/latest/userguide/build-caching.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:29.388Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.Cache")
public abstract class Cache extends software.amazon.jsii.JsiiObject {

    protected Cache(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Cache(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    protected Cache() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Create an S3 caching strategy.
     * <p>
     * @param bucket the S3 bucket to use for caching. This parameter is required.
     * @param options additional options to pass to the S3 caching.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.Cache bucket(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket bucket, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.codebuild.BucketCacheOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codebuild.Cache.class, "bucket", software.amazon.awscdk.services.codebuild.Cache.class, new Object[] { java.util.Objects.requireNonNull(bucket, "bucket is required"), options });
    }

    /**
     * Create an S3 caching strategy.
     * <p>
     * @param bucket the S3 bucket to use for caching. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.Cache bucket(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket bucket) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codebuild.Cache.class, "bucket", software.amazon.awscdk.services.codebuild.Cache.class, new Object[] { java.util.Objects.requireNonNull(bucket, "bucket is required") });
    }

    /**
     * Create a local caching strategy.
     * <p>
     * @param modes the mode(s) to enable for local caching. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.Cache local(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.LocalCacheMode... modes) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codebuild.Cache.class, "local", software.amazon.awscdk.services.codebuild.Cache.class, java.util.Arrays.<Object>stream(modes).toArray(Object[]::new));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.Cache none() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codebuild.Cache.class, "none", software.amazon.awscdk.services.codebuild.Cache.class);
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.awscdk.services.codebuild.Cache {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }
    }
}

==> codebuild-1.93.0-sources.jar: software/amazon/awscdk/services/codebuild/Cache.java <==
package software.amazon.awscdk.services.codebuild;

/**
 * Cache options for CodeBuild Project.
 * <p>
 * A cache can store reusable pieces of your build environment and use them across multiple builds.
 * <p>
 * @see https://docs.aws.amazon.com/codebuild/latest/userguide/build-caching.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.24.0 (build b722f66)", date = "2021-03-11T13:46:46.548Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.codebuild.$Module.class, fqn = "@aws-cdk/aws-codebuild.Cache")
public abstract class Cache extends software.amazon.jsii.JsiiObject {

    protected Cache(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Cache(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected Cache() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Create an S3 caching strategy.
     * <p>
     * @param bucket the S3 bucket to use for caching. This parameter is required.
     * @param options additional options to pass to the S3 caching.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.Cache bucket(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket bucket, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.codebuild.BucketCacheOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codebuild.Cache.class, "bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codebuild.Cache.class), new Object[] { java.util.Objects.requireNonNull(bucket, "bucket is required"), options });
    }

    /**
     * Create an S3 caching strategy.
     * <p>
     * @param bucket the S3 bucket to use for caching. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.Cache bucket(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.s3.IBucket bucket) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codebuild.Cache.class, "bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codebuild.Cache.class), new Object[] { java.util.Objects.requireNonNull(bucket, "bucket is required") });
    }

    /**
     * Create a local caching strategy.
     * <p>
     * @param modes the mode(s) to enable for local caching. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.Cache local(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.LocalCacheMode... modes) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codebuild.Cache.class, "local", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codebuild.Cache.class), java.util.Arrays.<Object>stream(modes).toArray(Object[]::new));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.codebuild.Cache none() {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.codebuild.Cache.class, "none", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.codebuild.Cache.class));
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends software.amazon.awscdk.services.codebuild.Cache {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }
    }
}
